Class: PostProxy::StatsRecord
Instance Attribute Summary collapse
-
#raw_stats ⇒ Object
raw_statscarries every metric under its original platform name, e.g. -
#recorded_at ⇒ Object
raw_statscarries every metric under its original platform name, e.g. -
#stats ⇒ Object
raw_statscarries every metric under its original platform name, e.g.
Instance Method Summary collapse
-
#initialize(**attrs) ⇒ StatsRecord
constructor
A new instance of StatsRecord.
Methods inherited from Model
Constructor Details
#initialize(**attrs) ⇒ StatsRecord
Returns a new instance of StatsRecord.
268 269 270 271 272 273 274 |
# File 'lib/postproxy/types.rb', line 268 def initialize(**attrs) @stats = {} @raw_stats = {} @recorded_at = nil super @recorded_at = parse_time(@recorded_at) end |
Instance Attribute Details
#raw_stats ⇒ Object
raw_stats carries every metric under its original platform name, e.g.
views for Instagram or impression_count for Twitter/X.
266 267 268 |
# File 'lib/postproxy/types.rb', line 266 def raw_stats @raw_stats end |
#recorded_at ⇒ Object
raw_stats carries every metric under its original platform name, e.g.
views for Instagram or impression_count for Twitter/X.
266 267 268 |
# File 'lib/postproxy/types.rb', line 266 def recorded_at @recorded_at end |
#stats ⇒ Object
raw_stats carries every metric under its original platform name, e.g.
views for Instagram or impression_count for Twitter/X.
266 267 268 |
# File 'lib/postproxy/types.rb', line 266 def stats @stats end |